@@ -60,8 +60,12 @@ def range_height(top_bot_rect, h: str):
 
 
 def rect_size(top_bot_rect, size):
+    """
+    return the size of grid (w, h)
+    """
     return (range_width(top_bot_rect, size[0]), range_height(top_bot_rect, size[1]))
 
+
 def bot_top_rect2top_bot_rect(bot_top_rect):
     """
     covert a bot_top_rect(left_bot_point, right_top_point) to top_bot_rect(left_top_point, right_bot_point)
@@ -84,17 +88,23 @@ a = 6378245.0
 
 
 def float_str_precision(s: str, precision='0.000000'):
+    """
+    set a float value which is kept by str precision  
+    """
     s = Decimal(s)
     return str(s.quantize(Decimal(precision)))
 
 
 def point_precision(point, precision='0.000000'):
+    """
+    set a point(lng, lat) precision
+    """
     return (float_str_precision(point[0], precision), float_str_precision(point[1], precision))
 
 
 def wgs84_to_gcj02(lng, lat):
     """
-    convert wgs84 to gcj02 (gaode)
+    convert wgs84 to gcj02 (高德)
     """
     dlat = transformlat(lng - 105.0, lat - 35.0)
     dlng = transformlng(lng - 105.0, lat - 35.0)
@@ -110,6 +120,9 @@ def wgs84_to_gcj02(lng, lat):
 
 
 def gcj02_to_wgs84(lng, lat):
+    """
+    convert gcj02 coordinate to wgs84 coordinate
+    """
     dlat = transformlat(lng - 105.0, lat - 35.0)
     dlng = transformlng(lng - 105.0, lat - 35.0)
     radlat = lat / 180.0 * PI
@@ -140,6 +153,9 @@ def transformlng(lng, lat):
 
 
 def wgs84_rect_to_gcj02_rect(wgs84_rect):
+    """
+    convert a rect whose coordinate is wgs84 to gcj02
+    """
     first_point = wgs84_to_gcj02(float(wgs84_rect[0][0]), float(wgs84_rect[0][1]))
     second_point = wgs84_to_gcj02(float(wgs84_rect[1][0]), float(wgs84_rect[1][1]))
     return [point_precision(first_point), point_precision(second_point)]
@@ -147,6 +163,9 @@ def wgs84_rect_to_gcj02_rect(wgs84_rect):
 
 
 def map_to_grid_left_top(left_top_rect, grid_size, point):
+    """
+    map a point(lng, lat) to a grid point
+    """
 
     left_top = (Decimal(left_top_rect[0][0]), Decimal(left_top_rect[0][1]))
 
@@ -172,6 +191,9 @@ def map_to_grid_left_top(left_top_rect, grid_size, point):
 
 
 def cut_rect_grid(top_bot_rect, step=None):
+    """
+    cut a rect to grids whose grid size is given by step
+    """
     left_top = top_bot_rect[RECT_LEFT_TOP]
     right_bot = top_bot_rect[RECT_RIGHT_BOT]
 
@@ -195,7 +217,9 @@ def cut_rect_grid(top_bot_rect, step=None):
         y = y - lat_diff
 
 def grid_index(top_bot_rect, size, grid):
-
+    """
+    return a grid index in rect by given rect and grid size
+    """
     b_left_top = top_bot_rect[RECT_LEFT_TOP]
     g_left_top = grid[RECT_LEFT_TOP]
 
@@ -216,7 +240,9 @@ def grid_index(top_bot_rect, size, grid):
 
 
 def grid_by_index(top_bot_rect, size, index):
-
+    """
+    return a grid by given index in rect and grid size 
+    """
     b_left_top = top_bot_rect[RECT_LEFT_TOP]
     
     w = Decimal(index[0])
@@ -234,8 +260,3 @@ def grid_by_index(top_bot_rect, size, index):
     return [point_precision((glng, glat), '0.00'), point_precision((glng + lng_diff, glat - lat_diff), '0.00')]
 
 
-# box = [('113.70', '31.37'), ('115.09', '29.96')]
-# size = ('0.01', '0.01')
-
-# print(grid_by_index(box, size, (1,0)))
-
